package javax.swing.border;

import java.awt.Rectangle;
import java.awt.Insets;
import java.awt.Graphics;
import java.awt.Component;
import java.io.Serializable;

public abstract class AbstractBorder implements Border, Serializable
{
    public AbstractBorder() {
    }
    
    @Override
    public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
    }
    
    @Override
    public Insets getBorderInsets(Component component) {
        return this.getBorderInsets(component, new Insets(0, 0, 0, 0));
    }
    
    public Insets getBorderInsets(Component component, Insets insets) {
        int n = 0;
        insets.bottom = n;
        insets.right = n;
        insets.top = n;
        insets.left = n;
        return insets;
    }
    
    @Override
    public boolean isBorderOpaque() {
        return false;
    }
    
    public Rectangle getInteriorRectangle(Component component, int n, int n2, int n3, int n4) {
        return getInteriorRectangle(component, this, n, n2, n3, n4);
    }
    
    public static Rectangle getInteriorRectangle(Component component, Border border, int n, int n2, int n3, int n4) {
        Insets borderInsets;
        if (border != null) {
            borderInsets = border.getBorderInsets(component);
        }
        else {
            borderInsets = new Insets(0, 0, 0, 0);
        }
        return new Rectangle(n + borderInsets.left, n2 + borderInsets.top, n3 - borderInsets.right - borderInsets.left, n4 - borderInsets.top - borderInsets.bottom);
    }
    
    public int getBaseline(Component component, int n, int n2) {
        if (n < 0 || n2 < 0) {
            throw new IllegalArgumentException("Width and height must be >= 0");
        }
        return -1;
    }
    
    public Component.BaselineResizeBehavior getBaselineResizeBehavior(Component component) {
        if (component == null) {
            throw new NullPointerException("Component must be non-null");
        }
        return Component.BaselineResizeBehavior.OTHER;
    }
    
    static boolean isLeftToRight(Component component) {
        return component.getComponentOrientation().isLeftToRight();
    }
}
